@@ -4,7 +4,7 @@
 #The original file is in cobalt/R/.
 
 #Strings
-word.list <- function(word.list = NULL, and.or = c("and", "or"), is.are = FALSE, quotes = FALSE) {
+word_list <- function(word.list = NULL, and.or = c("and", "or"), is.are = FALSE, quotes = FALSE) {
     #When given a vector of strings, creates a string of the form "a and b"
     #or "a, b, and c"
     #If is.are, adds "is" or "are" appropriately
@@ -44,6 +44,11 @@ word.list <- function(word.list = NULL, and.or = c("and", "or"), is.are = FALSE,
     }
     return(out)
 }
+firstup <- function(x) {
+    #Capitalize first letter
+    substr(x, 1, 1) <- toupper(substr(x, 1, 1))
+    x
+}
 expand.grid_string <- function(..., collapse = "") {
     return(apply(expand.grid(...), 1, paste, collapse = collapse))
 }
@@ -131,7 +136,7 @@ round_df_char <- function(df, digits, pad = "0", na_vals = "") {
     
     return(df)
 }
-text.box.plot <- function(range.list, width = 12) {
+text_box_plot <- function(range.list, width = 12) {
     full.range <- range(unlist(range.list))
     ratio = diff(full.range)/(width+1)
     rescaled.range.list <- lapply(range.list, function(x) round(x/ratio))
@@ -153,12 +158,21 @@ text.box.plot <- function(range.list, width = 12) {
     return(d)
 }
 equivalent.factors <- function(f1, f2) {
-    return(nunique(f1) == nunique(interaction(f1, f2)))
+    return(nunique(f1) == nunique(interaction(f1, f2, drop = TRUE)))
+}
+equivalent.factors2 <- function(f1, f2) {
+    return(qr(matrix(c(rep(1, length(f1)), as.numeric(f1), as.numeric(f2)), ncol = 3))$rank == 2)
 }
 paste. <- function(..., collapse = NULL) {
     #Like paste0 but with sep = ".'
     paste(..., sep = ".", collapse = collapse)
 }
+wrap <- function(s, nchar, ...) {
+    vapply(s, function(s_) {
+        x <- strwrap(s_, width = nchar, ...)
+        paste(x, collapse = "\n")
+    }, character(1L))
+}
 
 #Numbers
 check_if_zero <- function(x) {
@@ -186,23 +200,38 @@ between <- function(x, range, inclusive = TRUE, na.action = FALSE) {
 }
 
 #Statistics
-binarize <- function(variable) {
+binarize <- function(variable, zero = NULL, one = NULL) {
     nas <- is.na(variable)
     if (!is_binary(variable[!nas])) stop(paste0("Cannot binarize ", deparse(substitute(variable)), ": more than two levels."))
     if (is.character(variable)) variable <- factor(variable)
     variable.numeric <- as.numeric(variable)
-    if (0 %in% variable.numeric) zero <- 0
-    else zero <- min(variable.numeric, na.rm = TRUE)
-    newvar <- setNames(ifelse(!nas & variable.numeric==zero, 0L, 1L), names(variable))
+    if (is_null(zero)) {
+        if (is_null(one)) {
+            if (0 %in% variable.numeric) zero <- 0
+            else zero <- min(variable.numeric, na.rm = TRUE)
+        }
+        else {
+            if (one %in% levels(variable)) zero <- levels(variable)[levels(variable) != one]
+            else stop("The argument to \"one\" is not the name of a level of variable.", call. = FALSE)
+        }
+    }
+    else {
+        if (zero %in% levels(variable)) zero <- zero
+        else stop("The argument to \"zero\" is not the name of a level of variable.", call. = FALSE)
+    }
+    
+    newvar <- setNames(ifelse(!nas & variable.numeric == zero, 0L, 1L), names(variable))
     newvar[nas] <- NA_integer_
     return(newvar)
 }
 ESS <- function(w) {
     sum(w)^2/sum(w^2)
 }
-center <- function(x, na.rm = TRUE, at = NULL) {
-    if (!is.numeric(x)) warning("x is not numeric and will not be centered.")
-    else if (is.matrix(x)) x <- apply(x, 2, center, na.rm = na.rm, at = at)
+.center <- function(x, na.rm = TRUE, at = NULL) {
+    dimx <- dim(x)
+    if (length(dimx) == 2L) x <- apply(x, 2, center, na.rm = na.rm, at = at)
+    else if (length(dimx) > 2L) stop("x must be a numeric or matrix-like (not array).")
+    else if (!is.numeric(x)) warning("x is not numeric and will not be centered.")
     else {
         if (is_null(at)) at <- mean(x, na.rm = na.rm)
         else if (!is.numeric(at)) stop("at must be numeric.")
@@ -210,40 +239,98 @@ center <- function(x, na.rm = TRUE, at = NULL) {
     }
     return(x)
 }
+center <- function(x, at = NULL, na.rm = TRUE) {
+    if (is.data.frame(x)) {
+        x <- as.matrix.data.frame(x)
+        type <- "df"
+    }
+    if (!is.numeric(x)) stop("x must be numeric.")
+    else if (is.array(x) && length(dim(x)) > 2) stop("x must be a numeric or matrix-like (not array).")
+    else if (!is.matrix(x)) {
+        x <- matrix(x, ncol = 1)
+        type <- "vec"
+    }
+    else type <- "matrix"
+    if (is_null(at)) at <- colMeans(x, na.rm = na.rm)
+    else if (length(at) %nin% c(1, ncol(x))) stop("at is not the right length.")
+    out <- x - matrix(at, byrow = TRUE, ncol = ncol(x), nrow = nrow(x))
+    if (type == "df") out <- as.data.frame.matrix(out)
+    else if (type == "vec") out <- drop(out)
+    return(out)
+}
 w.m <- function(x, w = NULL, na.rm = TRUE) {
-    if (is_null(w)) w <- as.numeric(!is.na(x))
+    if (is_null(w)) w <- rep(1, length(x))
+    w[is.na(x)] <- NA_real_
     return(sum(x*w, na.rm=na.rm)/sum(w, na.rm=na.rm))
 }
-w.v <- function(x, w = NULL) {
-    # return(sum(w*(x-w.m(x, w))^2, na.rm=TRUE)/(sum(w, na.rm=TRUE)-1))
-    # return(sum(w*(x-w.m(x, w))^2, na.rm=TRUE) / w.cov.scale(w))
-    w.cov(x, x, w = w)
+w.v <- function(x, w = NULL, na.rm = TRUE) {
+    w.cov(x, x, w = w, na.rm = na.rm)
 }
-w.cov <- function(x, y, w = NULL) {
-    if (is_null(w)) w <- as.numeric(!is.na(x))
-    wmx <- w.m(x, w)
-    wmy <- w.m(y, w)
-    w.cov.scale <- (sum(w, na.rm = TRUE)^2 - sum(w^2, na.rm = TRUE)) / sum(w, na.rm = TRUE)
-    #wcov <- sum(w*(x - wmx)*(y - wmy), na.rm = TRUE)/sum(w, na.rm = TRUE)
-    wcov <- sum(w*(x - wmx)*(y - wmy), na.rm = TRUE) / w.cov.scale
+w.cov <- function(x, y, w = NULL, na.rm = TRUE, type = 3) {
+    
+    if (length(x) != length(y)) stop("x and y must the same length")
+    
+    if (is_null(w)) w <- rep(1, length(x))
+    else if (length(w) != length(x)) stop("weights must be same length as x and y")
+    
+    w[is.na(x) | is.na(y)] <- NA_real_
+    
+    wmx <- w.m(x, w, na.rm = na.rm)
+    wmy <- w.m(y, w, na.rm = na.rm)
+    
+    wcov <- sum(w*(x - wmx)*(y - wmy), na.rm = na.rm) / w.cov.scale(w, na.rm = na.rm, type = type)
     return(wcov)
 }
+w.cov.scale <- function(w, type = 3, na.rm = TRUE) {
+    
+    sw <- sum(w, na.rm = na.rm)
+    n <- sum(!is.na(w))
+    vw1 <- sum((w - sw/n)^2, na.rm = na.rm)/n
+    # vw2 <- sum((w - sw/n)^2, na.rm = na.rm)/(n-1)
+    
+    if (type == 1) sw
+    else if (type == 2) sw - 1
+    else if (type == 3) sw*(n-1)/n - vw1*n/sw
+    # else if (type == 4) sw*(n-1)/n - vw2*n/sw
+    
+}
+w.r <- function(x, y, w = NULL, s.weights = NULL) {
+    #Computes weighted correlation but using the unweighted (s.weighted) variances
+    #in the denominator.
+    if (is_null(s.weights)) s.weights <- rep(1, length(x))
+    else if (length(s.weights) != length(x)) stop("s.weights must be same length as x and y")
+    
+    s.weights[is.na(x) | is.na(y)] <- NA_real_
+    
+    w_ <- w*s.weights
+    
+    r <- w.cov(x, y, w_) / (sqrt(w.v(x, s.weights) * w.v(y, s.weights)))
+    
+    return(r)
+}
 col.w.m <- function(mat, w = NULL, na.rm = TRUE) {
     if (is_null(w)) {
         w <- 1
-        w.sum <- apply(mat, 2, function(x) sum(!is.na(x)))
-    }
-    else {
-        w.sum <- rep(sum(w, na.rm = na.rm), ncol(mat))
     }
+    w.sum <- colSums(w*!is.na(mat))
     return(colSums(mat*w, na.rm = na.rm)/w.sum)
 }
 col.w.v <- function(mat, w = NULL, na.rm = TRUE) {
     if (is_null(w)) {
         w <- rep(1, nrow(mat))
     }
-    w.cov.scale <- (sum(w, na.rm = TRUE)^2 - sum(w^2, na.rm = TRUE)) / sum(w, na.rm = TRUE)
-    return(colSums(t((t(mat) - col.w.m(mat, w, na.rm = na.rm))^2) * w, na.rm = na.rm) / w.cov.scale)
+    means <- col.w.m(mat, w, na.rm)
+    w.scale <- apply(mat, 2, function(x) w.cov.scale(w[!is.na(x)]))
+    vars <- colSums(w*t(t(mat) - means)^2, na.rm = na.rm)/w.scale
+    return(vars)
+}
+col.w.v.bin <- function(mat, w = NULL, na.rm = TRUE) {
+    if (is_null(w)) {
+        w <- rep(1, nrow(mat))
+    }
+    means <- col.w.m(mat, w, na.rm)
+    vars <- means * (1 - means)
+    return(vars)
 }
 coef.of.var <- function(x, pop = TRUE, na.rm = TRUE) {
     if (na.rm) x <- x[!is.na(x)]
@@ -257,7 +344,13 @@ mean.abs.dev <- function(x, na.rm = TRUE) {
 geom.mean <- function(y, na.rm = TRUE) {
     exp(mean(log(y[is.finite(log(y))]), na.rm = na.rm))
 }
-
+mat_div <- function(mat, vec) {
+    mat/vec[col(mat)]
+}
+abs_ <- function(x, ratio = FALSE) {
+    if (ratio) pmax(x, 1/x)
+    else (abs(x))
+}
 
 #Formulas
 is.formula <- function(f, sides = NULL) {
@@ -274,8 +367,15 @@ get.covs.and.treat.from.formula <- function(f, data = NULL, terms = FALSE, sep =
     A <- list(...)
     
     #Check if data exists
-    if (is_not_null(data) && is.data.frame(data)) {
-        data.specified <- TRUE
+    if (is_not_null(data)) {
+        if (is.data.frame(data)) {
+            data.specified <- TRUE
+        }
+        else {
+            warning("The argument supplied to data is not a data.frame object. This may causes errors or unexpected results.", call. = FALSE)
+            data <- environment(f)
+            data.specified <- FALSE
+        }
     }
     else {
         data <- environment(f)
@@ -284,17 +384,23 @@ get.covs.and.treat.from.formula <- function(f, data = NULL, terms = FALSE, sep =
     
     env <- environment(f)
     
-    tt <- terms(f)
+    tryCatch(tt <- terms(f, data = data),
+             error = function(e) {
+                 if (conditionMessage(e) == "'.' in formula and no 'data' argument") {
+                     stop("'.' is not allowed in formulas.", call. = FALSE)
+                 }
+                 else stop(conditionMessage(e), call. = FALSE)
+             })
     
     #Check if response exists
     if (is.formula(tt, 2)) {
         resp.vars.mentioned <- as.character(tt)[2]
         resp.vars.failed <- vapply(resp.vars.mentioned, function(v) {
-            null.or.error(try(eval(parse(text=v)[[1]], data, env), silent = TRUE))
+            null_or_error(try(eval(parse(text=v)[[1]], data, env), silent = TRUE))
         }, logical(1L))
         
         if (any(resp.vars.failed)) {
-            if (is_null(A[["treat"]])) stop(paste0("The given response variable, \"", as.character(tt)[2], "\", is not a variable in ", word.list(c("data", "the global environment")[c(data.specified, TRUE)], "or"), "."), call. = FALSE)
+            if (is_null(A[["treat"]])) stop(paste0("The given response variable, \"", as.character(tt)[2], "\", is not a variable in ", word_list(c("data", "the global environment")[c(data.specified, TRUE)], "or"), "."), call. = FALSE)
             tt <- delete.response(tt)
         }
     }
@@ -311,10 +417,11 @@ get.covs.and.treat.from.formula <- function(f, data = NULL, terms = FALSE, sep =
     
     #Check if RHS variables exist
     tt.covs <- delete.response(tt)
+    
     rhs.vars.mentioned.lang <- attr(tt.covs, "variables")[-1]
     rhs.vars.mentioned <- vapply(rhs.vars.mentioned.lang, deparse, character(1L))
     rhs.vars.failed <- vapply(rhs.vars.mentioned, function(v) {
-        null.or.error(try(eval(parse(text=v)[[1]], data, env), silent = TRUE))
+        null_or_error(try(eval(parse(text=v)[[1]], data, env), silent = TRUE))
     }, logical(1L))
     
     if (any(rhs.vars.failed)) {
@@ -344,13 +451,14 @@ get.covs.and.treat.from.formula <- function(f, data = NULL, terms = FALSE, sep =
                                       values = names(addl.dfs[[i]]),
                                       after = ind - 1)
         }
-        new.form <- as.formula(paste("~", paste(rhs.term.labels, collapse = " + ")))
         
-        tt.covs <- terms(new.form)
         if (data.specified) data <- do.call("cbind", unname(c(addl.dfs, list(data))))
         else data <- do.call("cbind", unname(addl.dfs))
     }
     
+    new.form <- as.formula(paste("~", paste(rhs.term.labels, collapse = " + ")))
+    tt.covs <- terms(new.form)
+    
     #Get model.frame, report error
     mf.covs <- quote(stats::model.frame(tt.covs, data,
                                         drop.unused.levels = TRUE,
@@ -398,7 +506,7 @@ get.covs.and.treat.from.formula <- function(f, data = NULL, terms = FALSE, sep =
                 treat = treat,
                 treat.name = treat.name))
 }
-get.treat.type <- function(treat) {
+assign.treat.type <- function(treat) {
     #Returns treat with treat.type attribute
     nunique.treat <- nunique(treat)
     if (nunique.treat == 2) {
@@ -417,6 +525,12 @@ get.treat.type <- function(treat) {
     attr(treat, "treat.type") <- treat.type
     return(treat)
 }
+get.treat.type <- function(treat) {
+    return(attr(treat, "treat.type"))
+}
+has.treat.type <- function(treat) {
+    is_not_null(get.treat.type(treat))
+}
 process.s.weights <- function(s.weights, data = NULL) {
     #Process s.weights
     if (is_not_null(s.weights)) {
@@ -465,7 +579,8 @@ is_ <- function(x, types, stop = FALSE, arg.to = FALSE) {
     s1 <- deparse(substitute(x))
     if (is_not_null(x)) {
         for (i in types) {
-            if (is_not_null(get0(paste.("is", i)))) {
+            if (i == "list") it.is <- is.vector(x, "list")
+            else if (is_not_null(get0(paste.("is", i)))) {
                 it.is <- get0(paste.("is", i))(x)
             }
             else it.is <- inherits(x, i)
@@ -479,7 +594,7 @@ is_ <- function(x, types, stop = FALSE, arg.to = FALSE) {
             s0 <- ifelse(arg.to, "The argument to ", "")
             s2 <- ifelse(any(types %in% c("factor", "character", "numeric", "logical")),
                          "vector", "")
-            stop(paste0(s0, s1, " must be a ", word.list(types, and.or = "or"), " ", s2, "."), call. = FALSE)
+            stop(paste0(s0, s1, " must be a ", word_list(types, and.or = "or"), " ", s2, "."), call. = FALSE)
         }
     }
     else {
@@ -498,7 +613,7 @@ probably.a.bug <- function() {
                 fun), call. = FALSE)
 }
 `%nin%` <- function(x, table) is.na(match(x, table, nomatch = NA_integer_))
-null.or.error <- function(x) {is_null(x) || class(x) == "try-error"}
+null_or_error <- function(x) {is_null(x) || class(x) == "try-error"}
 match_arg <- function(arg, choices, several.ok = FALSE) {
     #Replaces match.arg() but gives cleaner error message and processing
     #of arg.
@@ -527,10 +642,13 @@ match_arg <- function(arg, choices, several.ok = FALSE) {
     
     i <- pmatch(arg, choices, nomatch = 0L, duplicates.ok = TRUE)
     if (all(i == 0L))
-        stop(paste0("'", arg.name, "' should be one of ", word.list(choices, and.or = "or", quotes = TRUE), "."),
+        stop(paste0("'", arg.name, "' should be one of ", word_list(choices, and.or = "or", quotes = TRUE), "."),
              call. = FALSE)
     i <- i[i > 0L]
     if (!several.ok && length(i) > 1)
         stop("there is more than one match in 'match_arg'")
     choices[i]
 }
+last <- function(x) {
+    x[[length(x)]]
+}
